"""
forms for hazards app
"""
from hazards import models as app_models
from django import forms
from utils import forms as utils_forms
from utils import fields as utils_fields
from utils import lists as utils_lists
from utils import widgets as utils_widgets
from utils import sheets
from utils.versioning.versionedforms import VersionedForm, VersionedSheet
from django.utils.translation import ugettext_lazy as _

class SubstanceFilterForm(utils_lists.FilterForm):
    """Custom filterform for the substances list"""
    name = forms.CharField(max_length=100, required=False, label=_('Substance'),
        widget = utils_widgets.JQueryAutoCompleteTextInput(
                namedsource = 'hazards_substance_name_lookup'
            )
    )
    tag = forms.CharField(max_length=100, required=False, label=_('Tag'))
    class Meta:
        attrs = {
            'name': {'size': 30},
            'tag': {'size': 20},
        }

class SubstanceForm(VersionedForm):
    class Meta:
        model = app_models.Substance
        attrs = {
            'name': {'size': 75},
            'tag': {'size': 40},
            'description': {'rows':5,'cols':75},
            'hazards': {'rows':5,'cols':75},
        }
        widgets = {
            'description': utils_widgets.MarkItUpWidget(),
            'hazards': utils_widgets.MarkItUpWidget()
        }

class SubstanceSheet(VersionedSheet):
    description = utils_fields.MarkdownField(data = 'description', name='description', label=_('Description'))
    hazards = utils_fields.MarkdownField(data = 'hazards', name='hazards', label=_('Hazards'))
    class Meta:
        model = app_models.Substance

class ReactionFilterForm(utils_lists.FilterForm):
    """Custom filterform for the reactions list"""
    name = forms.CharField(max_length=100, required=False, label=_('Reaction'),
        widget = utils_widgets.JQueryAutoCompleteTextInput(
                namedsource = 'hazards_reaction_name_lookup'
            )
        )

class ReactionForm(VersionedForm):
    class Meta:
        model = app_models.Reaction
        attrs = {
            'name': {'size':75},
            'description': {'rows':5,'cols':75},
            'conditions': {'rows':5,'cols':75},
        }
        widgets = {
            'description': utils_widgets.MarkItUpWidget(),
            'conditions': utils_widgets.MarkItUpWidget()
        }

class ReactionSheet(VersionedSheet):
    description = utils_fields.MarkdownField(data = 'description', name='description', label=_('Description'))
    conditions = utils_fields.MarkdownField(data = 'conditions', name='conditions', label=_('Reaction conditions'))
    class Meta:
        model = app_models.Reaction
        links = ('substance1', 'substance2')

class MatrixReportForm(forms.Form):
    def __init__(self, user, *args, **kwargs):
        super(MatrixReportForm, self).__init__(*args, **kwargs)
        fields = utils_forms.treeify(app_models.Reaction.get_matrix_report_formfields(user))
        for k in fields:
            self.fields[k['name']] = k['field']
